[![PyPI version](https://badge.fury.io/py/sos-stata.svg)](https://badge.fury.io/py/sos-stata)

# sos-stata
SoS extension for Stata. Please refer to the [SoS homepage](http://vatlab.github.io/SOS) for more information.
